@@ -2,7 +2,7 @@
 import logging
 from redis import Redis
 from typing import Callable, Dict, Union, List
-from celery import Celery, Task
+from celery import Celery, Task, group
 from celery.result import AsyncResult
 from .common.exceptions import BizException
 from .common.utils import obj_to_ref, singleton
@@ -134,7 +134,7 @@ class CeleryClientHolder(object):
         CeleryClientHolder.__default_instance = CeleryClient(celery_broker_url, celery_result_backend, client_redis_uri, app_code)
 
     @staticmethod
-    def default_instance():
+    def get_default_instance():
         if not CeleryClientHolder.__default_instance:
             raise BizException(f'默认实例尚未初始化，请先初始化实例！')
         return CeleryClientHolder.__default_instance
